
.. _plot_api:

--------
CSDMAxes
--------


.. currentmodule:: csdmpy.helper_functions

.. autoclass:: CSDMAxes
    :show-inheritance:

    .. rubric:: Methods Summary

    .. autosummary::
       :nosignatures:

        ~CSDMAxes.plot
        ~CSDMAxes.imshow
        ~CSDMAxes.contour
        ~CSDMAxes.contourf

    .. rubric:: Method Documentation

    .. automethod:: plot
    .. automethod:: imshow
